@@ -154,7 +154,11 @@ class DocumentArrayField:
         return str(self.__parent_list)
 
     def __getitem__(self, item):
-        return self.__parent_list[item]
+        if isinstance(self.__parent_list[item], dict):
+            return DocumentField(
+                self.__parent_list[item], self.__update_immediately, self.__update_func)
+        else:
+            return self.__parent_list[item]
 
 
 class MetaDocument(type):
@@ -385,7 +389,7 @@ class Document(metaclass=MetaDocument):
     async def delete(self):
         """Delete current document."""
 
-        await self.delete_one({"_id": self._id})
+        return await self.delete_one({"_id": self._id})
 
     @staticmethod
     def lazy_property(self_field, other_field, multiple=True):
